import _ from 'lodash';
import React, { useCallback, useMemo, useState } from 'react';
import CustomFormField from '../form/CustomFormField';
import useUpdateEffect from '../hooks/useUpdateEffect';
import Pagination from './Pagination';
const TableSearch = ({
  paginatedItems,
  setPaginatedItems = () => {},
  fields = [],
  editItem = null,
  deleteItem = null,
  hideSearch = false
}) => {
  const [search, setSearch] = useState('');
  const [isLoading, setIsLoading] = useState(false);
  useUpdateEffect(() => {
    searchItems(search);
  }, [search]);
  const fetchItems = useCallback((search, page = 1) => {
    setIsLoading(true);
    Promise.resolve(setPaginatedItems(search, page)).then(() => setIsLoading(false));
  }, []);
  const searchItems = useCallback(_.debounce(search => fetchItems(search), 500), []);
  const displayActions = useMemo(() => editItem != null || deleteItem != null, [editItem, deleteItem]);
  return /*#__PURE__*/React.createElement(React.Fragment, null, paginatedItems != null && /*#__PURE__*/React.createElement("div", {
    className: "table-search"
  }, !hideSearch && /*#__PURE__*/React.createElement(CustomFormField, {
    label: "Rechercher",
    value: search,
    onChange: value => setSearch(value)
  }), !isLoading ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("table", {
    className: "table"
  }, /*#__PURE__*/React.createElement("thead", null, /*#__PURE__*/React.createElement("tr", null, fields.map((field, index) => /*#__PURE__*/React.createElement(React.Fragment, {
    key: index
  }, /*#__PURE__*/React.createElement("th", null, field.label))), displayActions && /*#__PURE__*/React.createElement("th", null))), /*#__PURE__*/React.createElement("tbody", null, paginatedItems.items.map((item, i) => /*#__PURE__*/React.createElement("tr", {
    key: i
  }, fields.map((field, j) => /*#__PURE__*/React.createElement("td", {
    key: j
  }, field.get(item))), displayActions && /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement("div", {
    className: "flex end spaced-inline"
  }, editItem != null && /*#__PURE__*/React.createElement("span", {
    className: "mdi mdi-pencil mdi-24px clickable text-primary",
    onClick: () => editItem(item)
  }), deleteItem != null && /*#__PURE__*/React.createElement("span", {
    className: "mdi mdi-delete mdi-24px clickable text-danger",
    onClick: () => deleteItem(item)
  }))))))), /*#__PURE__*/React.createElement(Pagination, {
    pagination: paginatedItems,
    fetch: page => fetchItems(search, page)
  })) : /*#__PURE__*/React.createElement("div", {
    className: "flex center"
  }, /*#__PURE__*/React.createElement("div", {
    className: "spinner-border text-primary",
    role: "status"
  }))));
};
export default TableSearch;